# pyenerginet
A python package to facilitate using public data from Energinet.
https://www.energidataservice.dk/


### Publishing
Set up following these guides:
- https://packaging.python.org/en/latest/tutorials/packaging-projects/
- https://packaging.python.org/en/latest/guides/publishing-package-distribution-releases-using-github-actions-ci-cd-workflows/

